==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/CONTRACTTEMPLATESALESPRICEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CONTRACTTEMPLATESALESPRICEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTTEMPLATESALESPRICEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATESALESPRICECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTTEMPLATESALESPRICEID_Type", propOrder = {
    "contracttemplatesalespricecode"
})
public class CONTRACTTEMPLATESALESPRICEID_Type {

    @XmlElement(name = "CONTRACTTEMPLATESALESPRICECODE", required = true)
    protected String contracttemplatesalespricecode;

    /**
     * Obtient la valeur de la propriété contracttemplatesalespricecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCONTRACTTEMPLATESALESPRICECODE() {
        return contracttemplatesalespricecode;
    }

    /**
     * Définit la valeur de la propriété contracttemplatesalespricecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCONTRACTTEMPLATESALESPRICECODE(String value) {
        this.contracttemplatesalespricecode = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/CONTRACTTEMPLATESALESPRICEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CONTRACTTEMPLATESALESPRICEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTTEMPLATESALESPRICEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATESALESPRICECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTTEMPLATESALESPRICEID_Type", propOrder = {
    "contracttemplatesalespricecode"
})
public class CONTRACTTEMPLATESALESPRICEID_Type {

    @XmlElement(name = "CONTRACTTEMPLATESALESPRICECODE", required = true)
    protected String contracttemplatesalespricecode;

    /**
     * Gets the value of the contracttemplatesalespricecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCONTRACTTEMPLATESALESPRICECODE() {
        return contracttemplatesalespricecode;
    }

    /**
     * Sets the value of the contracttemplatesalespricecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCONTRACTTEMPLATESALESPRICECODE(String value) {
        this.contracttemplatesalespricecode = value;
    }

}
